<?php $TRANSLATIONS = array(
"Invalid date/time" => "Неверные дата/время",
"Tasks" => "Задачи",
"Due" => "Задание",
"List" => "Список",
"Location" => "Местоположение",
"No category" => "Нет категории",
"Unspecified" => "Не указан",
"1=highest" => "1=наибольший",
"5=medium" => "5=средний",
"9=lowest" => "9=наименьший",
"Empty Summary" => "Пустая сводка",
"Invalid percent complete" => "Неверный процент завершения",
"Invalid priority" => "Неверный приоритет",
"The calendar application also need to be enabled to use this application." => "Для работы данного приложения необходимо включить приложение Calendar.",
"Add Task" => "Добавить задачу",
"Order Due" => "Срок заказа",
"Order List" => "Список заказов",
"Order Complete" => "Заказ выполнен",
"Order Location" => "Местонахождение заказа",
"Order Priority" => "Приоритет заказа",
"Order Label" => "Метка заказа",
"Loading tasks..." => "Загрузка задач...",
"Important" => "Важный",
"More" => "Больше",
"Less" => "Меньше",
"Delete" => "Удалить"
);
